@@ -2,25 +2,31 @@
 //!
 //! This module's structure mirrors `types`.
 
-use crate::pos::{PositionCalculator, Positioned};
-use crate::types::*;
-use crate::{Error, Result};
-use pest::iterators::{Pair, Pairs};
-use pest::Parser;
-use pest_derive::Parser;
-use std::collections::hash_map::{self, HashMap};
+use std::collections::{hash_map, HashMap};
+
+use pest::{
+    iterators::{Pair, Pairs},
+    Parser,
+};
 use utils::*;
 
+use crate::{
+    pos::{PositionCalculator, Positioned},
+    types::*,
+    Error, Result,
+};
+
 mod executable;
+#[allow(clippy::redundant_static_lifetimes)]
+mod generated;
 mod service;
 mod utils;
 
 use async_graphql_value::{ConstValue, Name, Number, Value};
 pub use executable::parse_query;
+use generated::Rule;
 pub use service::parse_schema;
 
-#[derive(Parser)]
-#[grammar = "graphql.pest"]
 struct GraphQLParser;
 
 fn parse_operation_type(
